@@ -1,6 +1,6 @@
 package Bundle::OpenILS;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 1;
 __END__
@@ -77,10 +77,17 @@ The web site for Open-ILS is: http://open-ils.org
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2005 by Joshua Ferraro
+Copyright (C) 2005 Georgia Public Library Service
+Joshua Ferraro E<lt>jmf@liblime.comE<gt>
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.8.6 or,
-at your option, any later version of Perl 5 you may have available.
+This program is free software; you can redistribute it and/or
+modify it under the terms of the GNU General Public License
+as published by the Free Software Foundation; either version 2
+of the License, or (at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
 
 =cut
